==> estateplat-common-1.2.3-20180529.081144-100-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXtZdqmpz.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import javax.persistence.Id;
import java.io.Serializable;

/**
 * 自动签名配置
 * Created by lst on 2015/3/18
 */
@Table(name = "BDC_XT_ZDQMPZ")
public class BdcXtZdqmpz implements Serializable {
    @Id
    private String id;//主键
    private String gzlid;//工作流ID
    private String gzlmc;//工作流名称
    private String jdmc;//节点名称
    private String jdid;//节点ID
    private String yhid;//用户ID
    private String yhmc;//用户名称
    private String qmbs;//签名标示
    private String qmfs;//签名方式
    private String dwdm;//单位代码
    private String mryj;//默认意见

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getGzlid() {
        return gzlid;
    }

    public void setGzlid(String gzlid) {
        this.gzlid = gzlid;
    }

    public String getGzlmc() {
        return gzlmc;
    }

    public void setGzlmc(String gzlmc) {
        this.gzlmc = gzlmc;
    }

    public String getJdmc() {
        return jdmc;
    }

    public void setJdmc(String jdmc) {
        this.jdmc = jdmc;
    }

    public String getJdid() {
        return jdid;
    }

    public void setJdid(String jdid) {
        this.jdid = jdid;
    }

    public String getYhid() {
        return yhid;
    }

    public void setYhid(String yhid) {
        this.yhid = yhid;
    }

    public String getYhmc() {
        return yhmc;
    }

    public void setYhmc(String yhmc) {
        this.yhmc = yhmc;
    }

    public String getQmbs() {
        return qmbs;
    }

    public void setQmbs(String qmbs) {
        this.qmbs = qmbs;
    }

    public String getQmfs() {
        return qmfs;
    }

    public void setQmfs(String qmfs) {
        this.qmfs = qmfs;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getMryj() {
        return mryj;
    }

    public void setMryj(String mryj) {
        this.mryj = mryj;
    }
}

==> estateplat-common-1.2.4-20191211.025513-208-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXtZdqmpz.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import javax.persistence.Id;
import java.io.Serializable;

/**
 * 自动签名配置
 * Created by lst on 2015/3/18
 */
@Table(name = "BDC_XT_ZDQMPZ")
public class BdcXtZdqmpz implements Serializable {
    @Id
    private String id;//主键
    private String gzlid;//工作流ID
    private String gzlmc;//工作流名称
    private String jdmc;//节点名称
    private String jdid;//节点ID
    private String yhid;//用户ID
    private String yhmc;//用户名称
    private String qmbs;//签名标示
    private String qmfs;//签名方式
    private String dwdm;//单位代码
    private String mryj;//默认意见
    private String xyzjdmc;//需验证节点名称

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getGzlid() {
        return gzlid;
    }

    public void setGzlid(String gzlid) {
        this.gzlid = gzlid;
    }

    public String getGzlmc() {
        return gzlmc;
    }

    public void setGzlmc(String gzlmc) {
        this.gzlmc = gzlmc;
    }

    public String getJdmc() {
        return jdmc;
    }

    public void setJdmc(String jdmc) {
        this.jdmc = jdmc;
    }

    public String getJdid() {
        return jdid;
    }

    public void setJdid(String jdid) {
        this.jdid = jdid;
    }

    public String getYhid() {
        return yhid;
    }

    public void setYhid(String yhid) {
        this.yhid = yhid;
    }

    public String getYhmc() {
        return yhmc;
    }

    public void setYhmc(String yhmc) {
        this.yhmc = yhmc;
    }

    public String getQmbs() {
        return qmbs;
    }

    public void setQmbs(String qmbs) {
        this.qmbs = qmbs;
    }

    public String getQmfs() {
        return qmfs;
    }

    public void setQmfs(String qmfs) {
        this.qmfs = qmfs;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getMryj() {
        return mryj;
    }

    public void setMryj(String mryj) {
        this.mryj = mryj;
    }

    public String getXyzjdmc() {
        return xyzjdmc;
    }

    public void setXyzjdmc(String xyzjdmc) {
        this.xyzjdmc = xyzjdmc;
    }
}
